@@ -1,15 +1,14 @@
 /*
-   SPDX-FileCopyrightText: 2017-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2017-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "handleclickedurljob.h"
-#include "composer.h"
-#include "editor/kmcomposerwin.h"
 #include "kmail_debug.h"
 #include "kmkernel.h"
 #include <KMime/Message>
+#include <MessageComposer/Composer>
 #include <MessageComposer/MessageHelper>
 #include <MessageCore/StringUtil>
 #include <TemplateParser/TemplateParserJob>
@@ -57,7 +56,6 @@ void HandleClickedUrlJob::start()
             const QString attach = element.second;
             if (!attach.isEmpty()) {
                 qCDebug(KMAIL_LOG) << "Attachment not supported yet";
-                // TODO
             }
         }
     }
